.. rnnr documentation master file, created by
   sphinx-quickstart on Thu Mar 14 20:36:48 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to rnnr's documentation!
================================

**rnnr** is an acronym for **rnnr: neural network runner**. As the name implies, its main
purpose is to ease running a neural network model, for either training or evaluation. **rnnr**
is heavily inspired by Ignite_ and torchnet_, but hopefully simpler and more applicable to
libraries other than PyTorch_.

.. toctree::
   :maxdepth: 2

   tutorial
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`


.. _PyTorch: https://pytorch.org
.. _Ignite: https://pytorch.org/ignite/index.html
.. _torchnet: https://github.com/pytorch/tnt/
